package com.zerohighdef.geoffrey.Commands;

import com.google.gson.JsonElement;
import com.zerohighdef.geoffrey.GeoffreyMC;
import com.zerohighdef.geoffrey.Models.GeoffreyLocation;
import com.zerohighdef.geoffrey.Models.GeoffreyMarket;
import com.zerohighdef.geoffrey.Models.GeoffreyShop;
import com.zerohighdef.geoffrey.Models.GeoffreyTown;
import com.zerohighdef.geoffrey.Objects.GeoffreyAPICallback;
import com.zerohighdef.geoffrey.Objects.GeoffreyCommand;
import com.zerohighdef.geoffrey.Objects.GeoffreyCommandError;
import com.zerohighdef.geoffrey.Objects.GeoffreyUtil;
import net.md_5.bungee.api.chat.ClickEvent;
import net.md_5.bungee.api.chat.TextComponent;
import org.bukkit.ChatColor;
import org.bukkit.command.Command;
import org.bukkit.command.CommandSender;

import java.text.ParseException;
import java.util.HashMap;
import java.util.Map;

public class InfoCommand extends GeoffreyCommand {
    public InfoCommand(GeoffreyMC plugin) {
        super(plugin);
    }

    @Override
    public boolean onCommand(CommandSender sender, Command command, String label, String[] args) {

        if (args.length > 0) {
            try {
                String locationName = GeoffreyUtil.parseArgs(args).get(0);
                Map<String, String> params = new HashMap<String, String>();

                params.put("location_name", locationName);
                RunCommand("info", params, Method.GET, new CommandCallback(sender, locationName));
            }
            catch (ParseException e) {
               sender.sendMessage(ChatColor.RED + e.getMessage());
            }
        }
        else {
            sender.sendMessage(ChatColor.RED + "You must specify a location name.");
            return false;
        }

        return true;
    }


    private class CommandCallback extends GeoffreyAPICallback {
        private String locationName;

        CommandCallback(CommandSender sender, String locationName) {
            super(sender);
            errors.put("LocationLookUpError", "There are no locations that match " + locationName + ".");
            this.locationName = locationName;
        }

        @Override
        public void invoke(String s) {
            try {
                JsonElement json = parseJSON(s);
                String locationType = json.getAsJsonObject().get("type").getAsString();

                String infoString;
                String url = plugin.getBaseURL();

                if (locationType.compareToIgnoreCase("shop") == 0) {
                   GeoffreyShop shop = new GeoffreyShop(json.getAsJsonObject());
                   infoString = shop.getInfoString();
                   url += shop.getLink();
                }
                else if (locationType.compareToIgnoreCase("town") == 0) {
                    GeoffreyTown town = new GeoffreyTown(json.getAsJsonObject());
                    infoString = town.getInfoString();
                    url += town.getLink();
                }
                else if (locationType.compareToIgnoreCase("market") == 0) {
                    GeoffreyMarket market = new GeoffreyMarket(json.getAsJsonObject());
                    infoString = market.getInfoString();
                    url += market.getLink();
                }
                else {
                    GeoffreyLocation location = new GeoffreyLocation(json.getAsJsonObject());
                    infoString = location.getInfoString();
                    url += location.getLink();
                }

                TextComponent message = new TextComponent();

                message.setText(infoString);
                message.setClickEvent(new ClickEvent(ClickEvent.Action.OPEN_URL, url));
                message.setColor(net.md_5.bungee.api.ChatColor.GREEN);
                commandSender.spigot().sendMessage(message);
            }
            catch (GeoffreyCommandError e) {
                return;
            }
        }
    }
}
